import { Button, Form, Image, Input, Modal, Select, Skeleton, Breadcrumb } from "antd";
import type { BreadcrumbProps } from "antd";
import { useMemo, useState } from "react";
import { useParams, useRequest, history } from "umi";
import { GetAppDetail } from "@/api/appStore";
import { GetTemplateDetail } from "@/api/templateStore";

export default function detail() {
  const [showAdvisory, setShowAdvisory] = useState(false);
  const [form] = Form.useForm();

  const handleSubmit = () => {
    form.validateFields().then((values) => {

      setShowAdvisory(false);
    });
  };

  const { id, type } = useParams();

  const { data, loading } = useRequest<{result: any}>(type === 'application' ? GetAppDetail : GetTemplateDetail, {
    defaultParams: [{
      id: id
    }]
  });

  const handleToApp = () => {
    if(data?.result?.trialUrl) {
      window.open(data?.result?.trialUrl, "_blank");
    }
  };

  const handleBack = () => {
    history.back();
  }

  const breadcrumbItems: BreadcrumbProps['items'] = useMemo(() => {
    return [
      { key: 'all', title: <a onClick={handleBack}>全部</a>},
      { key: 'current', title: data?.result.name}
    ]
  }, [data]);

  return (
    <div className="detail relative mx-auto pt-24px h-full overflow-y-auto">
      <div className="max-w-[1200px] mx-auto">
        <Breadcrumb className="mb-24px" items={breadcrumbItems}/>
        <Skeleton avatar active loading={loading}>
          <div className="flex mb-32px">
            <div className="w-128px h-128px rounded-20px bg-gray-200 overflow-hidden flex justify-center items-center">
              <Image className="w-full h-full" preview={false} src={data?.result?.icon ? `/api/File/Download?fileId=${data?.result?.icon}` : ''}/>
            </div>
            <div className="flex-1 mx-24px">
              <div className="text-32px font-[600]">{data?.result?.name}</div>
              <div className="text-secondary text-14px">
                {data?.result?.desc || '暂无描述'}
              </div>
              <div className="inline-block bg-[#dcdde0] rounded-8px text-secondary px-8px py-4px mt-12px text-12px">
                <i className="iconfont icon-qiyexinxi mr-8px" />
                <span>{data?.result?.createByName || '易码工坊'}</span>
              </div>
            </div>
            <div className="head-right flex flex-col justify-center items-center">
              <Button type="primary" className="w-full mb-24px" onClick={handleToApp}>
                在线体验
              </Button>
              <Button className="w-full" onClick={() => setShowAdvisory(true)}>
                购买咨询
              </Button>
            </div>
          </div>
        </Skeleton>
        <div className="inline-block">
          <div className="text-24px font-[600] mb-8px">方案详情</div>
          <div className="w-60px h-4px bg-primary rounded-4px mx-auto" />
        </div>

        <Skeleton active loading={loading}>
          <div className="content m-y-32px overflow-hidden relative">
            <div dangerouslySetInnerHTML={{__html: data?.result?.detail || ''}}/>
          </div>
        </Skeleton>
        
      </div>
      <Modal title="购买咨询" width={500} open={showAdvisory} onCancel={() => setShowAdvisory(false)} onOk={handleSubmit}>
        <Form labelCol={{ span: 5 }} autoComplete="off" form={form}>
          <Form.Item
            label="如何称呼您?"
            name="name"
            rules={[{ required: true, message: "请输入您的称呼！" }]}
          >
            <Input placeholder="请输入" maxLength={20} />
          </Form.Item>
          <Form.Item
            label="联系方式"
            name="phone"
            rules={[{ required: true, message: "请输入您的联系方式！" }]}
          >
            <Input placeholder="请输入" maxLength={20} />
          </Form.Item>
          <Form.Item label="公司名称" name="company">
            <Input placeholder="请输入" maxLength={100} />
          </Form.Item>
          <Form.Item label="企业规模" name="scale">
            <Select
              placeholder="请选择"
              options={[
                { label: "1-10人", value: "1-10人" },
                { label: "11-50人", value: "11-50人" },
                { label: "51-200人", value: "51-200人" },
                { label: "200人以上", value: "200人以上" },
              ]}
            />
          </Form.Item>
          <Form.Item label="您的职务" name="position">
            <Input placeholder="请输入" maxLength={20} />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
}
